#
# spec file for package cutmp3
#
# Copyright (c) 2023 SUSE LLC
# Copyright (c) 2013 Packman Team <packman@links2linux.de>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           cutmp3
Version:        3.0.3
Release:        bp160.1.7
Summary:        Command line based lossless MP3 editor
License:        GPL-2.0-or-later
Group:          Productivity/Multimedia/Sound/Editors and Convertors
URL:            https://www.puchalla-online.de/cutmp3.html
#Source:         https://www.puchalla-online.de/cutmp3-%%{version}.tar.bz2
Source0:        https://github.com/tarjanm-movidius/cutmp3/archive/refs/tags/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
Source1:        https://www.puchalla-online.de/cutmp3-keys.pdf
Source2:        https://www.puchalla-online.de/cutmp3-keys.jpg
Source99:       %{name}-rpmlintrc
BuildRequires:  ncurses-devel
BuildRequires:  pkgconfig
BuildRequires:  readline-devel
Requires:       mpg123
Obsoletes:      %{name}-kde3

%description
This is a program to split MP3 files without quality loss, using an
ncurses-based user interface. Beginning and end of a segment can be
marked with the 'a' and 'b' keys and the segment be saved with 's'.
VBR files are supported. Using a timetable with VBR files will not be
as precise as with CBR files, though.

%package doc
Summary:        Documentation for %{name}
Group:          Documentation/Other
BuildArch:      noarch
Requires:       %{name} = %{version}

%description doc
This is a program to edit MP3 files without quality loss, using an
ncurses-based user interface.

This package contains a user guide and a list of key bindings for %{name}

%prep
%autosetup -p1

%build
%make_build CFLAGS="%{optflags}"

%install
install -m 0755 -D cutmp3 "%{buildroot}%{_bindir}/cutmp3"
install -D -m 0644 cutmp3.1 "%{buildroot}%{_mandir}/man1/cutmp3.1"
install -d "%{buildroot}%{_docdir}/%{name}"
D="$PWD/main.doc.lst"
echo -n >"$D"
for f in BUGS USAGE README*; do
    b="${f##*/}"
    install -m0644 "$f" "%{buildroot}%{_docdir}/%{name}/$b"
    echo "%doc %{_docdir}/%{name}/$b" >>"$D"
done

D="$PWD/doc.doc.lst"
echo -n >"$D"
for f in "%{SOURCE1}" "%{SOURCE2}" TODO Changelog; do
    b="${f##*/}"
    install -m0644 "$f" "%{buildroot}%{_docdir}/%{name}/$b"
    echo "%doc %{_docdir}/%{name}/$b" >>"$D"
done

%files -f main.doc.lst
%license COPYING
%dir %doc %{_docdir}/%{name}
%{_bindir}/%{name}
%{_mandir}/man1/%{name}.1%{ext_man}

%files doc -f doc.doc.lst
%dir %doc %{_docdir}/%{name}

%changelog
* Sat Oct 14 2023 Luigi Baldoni <aloisio@gmx.com>
- Update to version 3.0.3
  * Quickfix, eliminated warnings -Wunused-result and
  - Wformat-security
  version 3.0.2:
  * Minor bugfixes, eliminated warnings
- Switch to new upstream source
* Fri Aug 25 2017 jengelh@inai.de
- Make description more neutral.
* Fri Aug 18 2017 aloisio@gmx.com
- Update to version 3.0.1
  * fix for non-interactive mode by Richard Fuchs
  version 3.0:
  * cutmp3 always uses exact times now, without being slow
  * improved silence seeking
  * much faster negative times seeking for cutting from timetable
  * better ID3V2 parsing
  * new parameter "-k" keeps old filename and path and appends
    0001.mp3, etc.
  version 2.1.2:
  * old tempfile is removed just before playing new tempfile.
    Patch by Till Maas.
- Spec cleanup
* Mon Apr  1 2013 pascal.bleser@opensuse.org
- update to 2.1.1:
  * small time display fix
  * fixed eading ID3V2
* Mon Sep 26 2011 pascal.bleser@opensuse.org
- update to 2.1:
  * layer 2 (MP2 file) support
* Sat May  7 2011 pascal.bleser@opensuse.org
- update to 2.0.3:
  * opening a file has been prevented when writing to STDOUT
- split out -doc subpackage
- obsolete -kde3 subpackage
* Sun Jun  6 2010 pascal@links2linux.de
- update to 2.0.2:
  * changes in the layout and in the playback behaviour
* Sun Jul 12 2009 pascal.bleser@opensuse.org
- update to 2.0.1:
  * security fixes have been made
  * giving times for cutting has been made easier
* Mon Jun 29 2009 pascal.bleser@opensuse.org
- update to 2.0:
  * live time display has been added, pressing "l" toggles it
  * the "-o" switch now always uses the given prefix instead of information from ID3
* Sun Apr 19 2009 pascal.bleser@opensuse.org
- update to 1.9.5:
  * pressing M and N now really changes the length of playback
* Wed Jan  7 2009 guru@unixtech.be
- update to 1.9.4
* Fri Apr  6 2007 guru@unixtech.be
- new upstream version
* Thu Dec  7 2006 guru@unixtech.be
- new upstream version
* Mon Feb 27 2006 guru@unixtech.be
- new upstream version
* Mon May 16 2005 guru@unixtech.be
- version 1.8.3
* Thu Apr 28 2005 guru@unixtech.be
- version 1.8.2
* Sun Nov  7 2004 guru@unixtech.be
- version 1.8.1
* Fri Oct 15 2004 guru@unixtech.be
- version 1.8
* Thu Jul 22 2004 guru@unixtech.be
- version 1.6.3
* Tue Jun 22 2004 guru@unixtech.be
- version 1.6
* Sun Jun 13 2004 guru@unixtech.be
- version 1.5.2
* Mon Apr 26 2004 guru@unixtech.be
- version 1.4
* Sun Feb 29 2004 guru@unixtech.be
- version 1.3
* Sun Nov 23 2003 guru@unixtech.be
- version 1.1.1
* Sun Nov  2 2003 guru@unixtech.be
- added KDE3 service menu
- version 1.0
* Tue Jul 29 2003 guru@unixtech.be
- first RPM
